@@ -30,6 +30,7 @@ JPH_SUPPRESS_WARNINGS_STD_BEGIN
 #include <chrono>
 #include <memory>
 #include <cstdarg>
+#include <filesystem>
 JPH_SUPPRESS_WARNINGS_STD_END
 
 using namespace JPH;
@@ -43,6 +44,9 @@ JPH_SUPPRESS_WARNINGS
 #include "RagdollScene.h"
 #include "ConvexVsMeshScene.h"
 #include "PyramidScene.h"
+#include "LargeMeshScene.h"
+#include "CharacterVirtualScene.h"
+#include "MaxBodiesScene.h"
 
 // Time step for physics
 constexpr float cDeltaTime = 1.0f / 60.0f;
@@ -112,6 +116,12 @@ int main(int argc, char** argv)
 				scene = unique_ptr<PerformanceTestScene>(new ConvexVsMeshScene);
 			else if (strcmp(arg + 3, "Pyramid") == 0)
 				scene = unique_ptr<PerformanceTestScene>(new PyramidScene);
+			else if (strcmp(arg + 3, "LargeMesh") == 0)
+				scene = unique_ptr<PerformanceTestScene>(new LargeMeshScene);
+			else if (strcmp(arg + 3, "CharacterVirtual") == 0)
+				scene = unique_ptr<PerformanceTestScene>(new CharacterVirtualScene);
+			else if (strcmp(arg + 3, "MaxBodies") == 0)
+				scene = unique_ptr<MaxBodiesScene>(new MaxBodiesScene);
 			else
 			{
 				Trace("Invalid scene");
@@ -208,21 +218,52 @@ int main(int argc, char** argv)
 	// Register all Jolt physics types
 	RegisterTypes();
 
-	// Create temp allocator
-	TempAllocatorImpl temp_allocator(32 * 1024 * 1024);
-
-	// Load the scene
-	if (scene == nullptr)
-		scene = create_ragdoll_scene();
-	if (!scene->Load())
-		return 1;
-
 	// Show used instruction sets
 	Trace(GetConfigurationString());
 
+	// If no scene was specified use the default scene
+	if (scene == nullptr)
+		scene = create_ragdoll_scene();
+
 	// Output scene we're running
 	Trace("Running scene: %s", scene->GetName());
 
+	// Create temp allocator
+	TempAllocatorImpl temp_allocator(scene->GetTempAllocatorSizeMB() * 1024 * 1024);
+
+	// Find the asset path
+	bool found = false;
+	filesystem::path asset_path(argv[0]);
+	filesystem::path root_path = asset_path.root_path();
+	while (asset_path != root_path)
+	{
+		asset_path = asset_path.parent_path();
+		if (filesystem::exists(asset_path / "Assets"))
+		{
+			found = true;
+			break;
+		}
+	}
+	if (!found) // Note that argv[0] can be a relative path like './PerformanceTest' so we also scan up using '..'
+		for (int i = 0; i < 5; ++i)
+		{
+			asset_path /= "..";
+			if (filesystem::exists(asset_path / "Assets"))
+			{
+				found = true;
+				break;
+			}
+		}
+	if (!found)
+		asset_path = "Assets";
+	else
+		asset_path /= "Assets";
+	asset_path /= "";
+
+	// Load the scene
+	if (!scene->Load(String(asset_path.string())))
+		return 1;
+
 	// Create mapping table from object layer to broadphase layer
 	BPLayerInterfaceImpl broad_phase_layer_interface;
 
@@ -268,7 +309,7 @@ int main(int argc, char** argv)
 
 				// Create physics system
 				PhysicsSystem physics_system;
-				physics_system.Init(10240, 0, 65536, 20480, broad_phase_layer_interface, object_vs_broadphase_layer_filter, object_vs_object_layer_filter);
+				physics_system.Init(scene->GetMaxBodies(), 0, scene->GetMaxBodyPairs(), scene->GetMaxContactConstraints(), broad_phase_layer_interface, object_vs_broadphase_layer_filter, object_vs_object_layer_filter);
 
 				// Start test scene
 				scene->StartTest(physics_system, motion_quality);
@@ -332,6 +373,9 @@ int main(int argc, char** argv)
 					// Start measuring
 					chrono::high_resolution_clock::time_point clock_start = chrono::high_resolution_clock::now();
 
+					// Update the test
+					scene->UpdateTest(physics_system, temp_allocator, cDeltaTime);
+
 					// Do a physics step
 					physics_system.Update(cDeltaTime, 1, &temp_allocator, &job_system);
 
@@ -419,6 +463,9 @@ int main(int argc, char** argv)
 					hash = HashBytes(&rot, sizeof(Quat), hash);
 				}
 
+				// Let the scene hash its own state
+				scene->UpdateHash(hash);
+
 				// Convert hash to string
 				stringstream hash_stream;
 				hash_stream << "0x" << hex << hash << dec;
