@@ -6,12 +6,17 @@
 
 #include <Tests/Test.h>
 
-// Tests a small box falling on a big triangle to test for numerical precision errors.
 class BigVsSmallTest : public Test
 {
 public:
 	JPH_DECLARE_RTTI_VIRTUAL(JPH_NO_EXPORT, BigVsSmallTest)
 
+	// Description of the test
+	virtual const char *GetDescription() const override
+	{
+		return "A small box falling on a big triangle to test for numerical precision errors.";
+	}
+
 	// See: Test
 	virtual void		Initialize() override;
 };
