@@ -6,12 +6,17 @@
 
 #include <Tests/Test.h>
 
-// Test that spawns various shapes with the center of mass not in the center of the object
 class CenterOfMassTest : public Test
 {
 public:
 	JPH_DECLARE_RTTI_VIRTUAL(JPH_NO_EXPORT, CenterOfMassTest)
 
+	// Description of the test
+	virtual const char *GetDescription() const override
+	{
+		return "Spawns various shapes with the center of mass not in the center of the object.";
+	}
+
 	// See: Test
 	virtual void		Initialize() override;
 };
