@@ -29,6 +29,7 @@ void DampingTest::Initialize()
 		body.GetMotionProperties()->SetLinearDamping(0.1f * i);
 		body.SetLinearVelocity(Vec3(0, 0, 10));
 		mBodyInterface->AddBody(body.GetID(), EActivation::Activate);
+		SetBodyLabel(body.GetID(), StringFormat("Linear damping: %.1f", double(body.GetMotionProperties()->GetLinearDamping())));
 	}
 
 	for (int i = 0; i <= 10; ++i)
@@ -38,5 +39,6 @@ void DampingTest::Initialize()
 		body.GetMotionProperties()->SetAngularDamping(0.1f * i);
 		body.SetAngularVelocity(Vec3(0, 10, 0));
 		mBodyInterface->AddBody(body.GetID(), EActivation::Activate);
+		SetBodyLabel(body.GetID(), StringFormat("Angular damping: %.1f", double(body.GetMotionProperties()->GetAngularDamping())));
 	}
 }
