@@ -6,12 +6,17 @@
 
 #include <Tests/Test.h>
 
-// This test tests various values for friction
 class FrictionTest : public Test
 {
 public:
 	JPH_DECLARE_RTTI_VIRTUAL(JPH_NO_EXPORT, FrictionTest)
 
+	// Description of the test
+	virtual const char *GetDescription() const override
+	{
+		return "Bodies with varying friction.";
+	}
+
 	// See: Test
 	virtual void		Initialize() override;
 };
