@@ -7,12 +7,18 @@
 #include <Tests/Test.h>
 #include <Jolt/Physics/Body/BodyActivationListener.h>
 
-// This shows how to enable gyrosopic forces to create the Dzhanibekov effect (see: https://en.wikipedia.org/wiki/Tennis_racket_theorem)
 class GyroscopicForceTest : public Test
 {
 public:
 	JPH_DECLARE_RTTI_VIRTUAL(JPH_NO_EXPORT, GyroscopicForceTest)
 
+	// Description of the test
+	virtual const char *GetDescription() const override
+	{
+		// See: https://en.wikipedia.org/wiki/Tennis_racket_theorem
+		return "Shows how to enable gyroscopic forces to create the Dzhanibekov effect.";
+	}
+
 	// See: Test
 	virtual void		Initialize() override;
 };
