@@ -6,12 +6,18 @@
 
 #include <Tests/Test.h>
 
-// This test spawns a number of heavy boxes (with increasing weight) on smaller boxes to see how the simulation handles this
 class HeavyOnLightTest : public Test
 {
 public:
 	JPH_DECLARE_RTTI_VIRTUAL(JPH_NO_EXPORT, HeavyOnLightTest)
 
+	// Description of the test
+	virtual const char *GetDescription() const override
+	{
+		return	"This test spawns a number of heavy boxes (with increasing weight) on light boxes.\n"
+				"Shows that iterative solvers have issues with large mass differences.";
+	}
+
 	// See: Test
 	virtual void		Initialize() override;
 };
