@@ -27,7 +27,6 @@ void IslandTest::Initialize()
 			for (int k = 0; k < 8; ++k)
 			{
 				RVec3 position(-10 + j * 2.0f + (i & 1? 1.0f : 0.0f), 1.0f + i * 2.0f, 8.0f * (k - 4));
-				Body &wall = *mBodyInterface->CreateBody(BodyCreationSettings(box_shape, position, Quat::sIdentity(), EMotionType::Dynamic, Layers::MOVING));
-				mBodyInterface->AddBody(wall.GetID(), EActivation::Activate);
+				mBodyInterface->CreateAndAddBody(BodyCreationSettings(box_shape, position, Quat::sIdentity(), EMotionType::Dynamic, Layers::MOVING), EActivation::Activate);
 			}
 }
