@@ -6,12 +6,17 @@
 
 #include <Tests/Test.h>
 
-// This test tests the binary serialization system by creating a number of shapes, storing them, loading them and then simulating them
 class LoadSaveBinaryTest : public Test
 {
 public:
 	JPH_DECLARE_RTTI_VIRTUAL(JPH_NO_EXPORT, LoadSaveBinaryTest)
 
+	// Description of the test
+	virtual const char *GetDescription() const override
+	{
+		return "Tests the binary serialization system by creating a number of shapes, storing them, loading them and then simulating them.";
+	}
+
 	// See: Test
 	virtual void		Initialize() override;
 };
