@@ -7,12 +7,17 @@
 #include <Tests/Test.h>
 #include <Jolt/Physics/PhysicsScene.h>
 
-// This test tests the serialization system by creating a number of shapes, storing them, loading them and then simulating them
 class LoadSaveSceneTest : public Test
 {
 public:
 	JPH_DECLARE_RTTI_VIRTUAL(JPH_NO_EXPORT, LoadSaveSceneTest)
 
+	// Description of the test
+	virtual const char *		GetDescription() const override
+	{
+		return "Tests the object stream serialization system by creating a number of shapes, storing them, loading them and then simulating them.";
+	}
+
 	// See: Test
 	virtual void				Initialize() override;
 
