@@ -7,7 +7,6 @@
 #include <Tests/Test.h>
 #include <Jolt/Physics/Ragdoll/Ragdoll.h>
 
-// Test that contains a sensor that will apply forces to bodies inside the sensor
 class SensorTest : public Test, public ContactListener
 {
 public:
@@ -15,6 +14,12 @@ public:
 
 	virtual				~SensorTest() override;
 
+	// Description of the test
+	virtual const char *GetDescription() const override
+	{
+		return	"Different types of sensors. See the description of each sensor.";
+	}
+
 	// Number used to scale the terrain and camera movement to the scene
 	virtual float		GetWorldScale() const override		{ return 0.2f; }
 
