@@ -29,7 +29,6 @@ void StackTest::Initialize()
 			rotation = Quat::sRotation(Vec3::sAxisY(), 0.5f * JPH_PI);
 		else
 			rotation = Quat::sIdentity();
-		Body &stack = *mBodyInterface->CreateBody(BodyCreationSettings(box_shape, RVec3(10, 1.0f + i * 2.1f, 0), rotation, EMotionType::Dynamic, Layers::MOVING));
-		mBodyInterface->AddBody(stack.GetID(), EActivation::Activate);
+		mBodyInterface->CreateAndAddBody(BodyCreationSettings(box_shape, RVec3(10, 1.0f + i * 2.1f, 0), rotation, EMotionType::Dynamic, Layers::MOVING), EActivation::Activate);
 	}
 }
