@@ -6,12 +6,17 @@
 
 #include <Tests/Test.h>
 
-// This test stacks a number of boxes to see if the simulation is stable
 class StackTest : public Test
 {
 public:
 	JPH_DECLARE_RTTI_VIRTUAL(JPH_NO_EXPORT, StackTest)
 
+	// Description of the test
+	virtual const char *GetDescription() const override
+	{
+		return "Stacks a number of boxes to see if the simulation is stable.";
+	}
+
 	// See: Test
 	virtual void		Initialize() override;
 };
