@@ -7,12 +7,17 @@
 #include <Tests/Test.h>
 #include <Jolt/Physics/SoftBody/SoftBodyContactListener.h>
 
-// This test shows how to use contact listeners for soft bodies
 class SoftBodyContactListenerTest : public Test, public SoftBodyContactListener
 {
 public:
 	JPH_DECLARE_RTTI_VIRTUAL(JPH_NO_EXPORT, SoftBodyContactListenerTest)
 
+	// Description of the test
+	virtual const char *			GetDescription() const override
+	{
+		return "Shows how to use contact listeners for soft bodies to affect the simulation.";
+	}
+
 	// See: Test
 	virtual void					Initialize() override;
 	virtual void					PrePhysicsUpdate(const PreUpdateParams &inParams) override;
@@ -26,6 +31,8 @@ public:
 	virtual void					OnSoftBodyContactAdded(const Body &inSoftBody, const SoftBodyManifold &inManifold) override;
 
 private:
+	void							UpdateLabel();
+
 	void							StartCycle();
 
 	float							mTime = 0.0f;
