@@ -7,12 +7,17 @@
 #include <Tests/Test.h>
 #include <Jolt/Physics/SoftBody/SoftBodyContactListener.h>
 
-// This test shows interaction between a soft body and a sensor
 class SoftBodySensorTest : public Test, public SoftBodyContactListener
 {
 public:
 	JPH_DECLARE_RTTI_VIRTUAL(JPH_NO_EXPORT, SoftBodySensorTest)
 
+	// Description of the test
+	virtual const char *GetDescription() const override
+	{
+		return "Shows interaction between a soft body and a sensor.";
+	}
+
 	// See: Test
 	virtual void		Initialize() override;
 
