@@ -6,12 +6,17 @@
 
 #include <Tests/Test.h>
 
-// This test shows interaction between a fast moving (CCD) object and a soft body
 class SoftBodyVsFastMovingTest : public Test
 {
 public:
 	JPH_DECLARE_RTTI_VIRTUAL(JPH_NO_EXPORT, SoftBodyVsFastMovingTest)
 
+	// Description of the test
+	virtual const char *GetDescription() const override
+	{
+		return "Shows interaction between a fast moving (CCD) object and a soft body.";
+	}
+
 	// See: Test
 	virtual void		Initialize() override;
 };
