@@ -176,9 +176,9 @@ void VehicleConstraintTest::ProcessInput(const ProcessInputParams &inParams)
 {
 	// Determine acceleration and brake
 	mForward = 0.0f;
-	if (inParams.mKeyboard->IsKeyPressed(DIK_UP))
+	if (inParams.mKeyboard->IsKeyPressed(EKey::Up))
 		mForward = 1.0f;
-	else if (inParams.mKeyboard->IsKeyPressed(DIK_DOWN))
+	else if (inParams.mKeyboard->IsKeyPressed(EKey::Down))
 		mForward = -1.0f;
 
 	// Check if we're reversing direction
@@ -202,7 +202,7 @@ void VehicleConstraintTest::ProcessInput(const ProcessInputParams &inParams)
 
 	// Hand brake will cancel gas pedal
 	mHandBrake = 0.0f;
-	if (inParams.mKeyboard->IsKeyPressed(DIK_Z))
+	if (inParams.mKeyboard->IsKeyPressed(EKey::Z))
 	{
 		mForward = 0.0f;
 		mHandBrake = 1.0f;
@@ -210,9 +210,9 @@ void VehicleConstraintTest::ProcessInput(const ProcessInputParams &inParams)
 
 	// Steering
 	mRight = 0.0f;
-	if (inParams.mKeyboard->IsKeyPressed(DIK_LEFT))
+	if (inParams.mKeyboard->IsKeyPressed(EKey::Left))
 		mRight = -1.0f;
-	else if (inParams.mKeyboard->IsKeyPressed(DIK_RIGHT))
+	else if (inParams.mKeyboard->IsKeyPressed(EKey::Right))
 		mRight = 1.0f;
 }
 
@@ -249,7 +249,7 @@ void VehicleConstraintTest::PrePhysicsUpdate(const PreUpdateParams &inParams)
 		// When overriding gravity is requested, we cast a sphere downwards (opposite to the previous up position) and use the contact normal as the new gravity direction
 		SphereShape sphere(0.5f);
 		sphere.SetEmbedded();
-		RShapeCast shape_cast(&sphere, Vec3::sReplicate(1.0f), RMat44::sTranslation(mCarBody->GetPosition()), -3.0f * mVehicleConstraint->GetWorldUp());
+		RShapeCast shape_cast(&sphere, Vec3::sOne(), RMat44::sTranslation(mCarBody->GetPosition()), -3.0f * mVehicleConstraint->GetWorldUp());
 		ShapeCastSettings settings;
 		ClosestHitCollisionCollector<CastShapeCollector> collector;
 		mPhysicsSystem->GetNarrowPhaseQuery().CastShape(shape_cast, settings, mCarBody->GetPosition(), collector, SpecifiedBroadPhaseLayerFilter(BroadPhaseLayers::NON_MOVING), SpecifiedObjectLayerFilter(Layers::NON_MOVING));
