@@ -17,6 +17,7 @@
 #include <Jolt/ObjectStream/ObjectStreamOut.h>
 #include <Layers.h>
 #include <Utils/Log.h>
+#include <Utils/AssetStream.h>
 
 #ifdef JPH_OBJECT_STREAM
 
@@ -24,7 +25,8 @@ RagdollSettings *RagdollLoader::sLoad(const char *inFileName, EMotionType inMoti
 {
 	// Read the ragdoll
 	RagdollSettings *ragdoll = nullptr;
-	if (!ObjectStreamIn::sReadObject(inFileName, ragdoll))
+	AssetStream stream(inFileName, std::ios::in);
+	if (!ObjectStreamIn::sReadObject(stream.Get(), ragdoll))
 		FatalError("Unable to read ragdoll");
 
 	for (RagdollSettings::Part &p : ragdoll->mParts)
