@@ -9,6 +9,8 @@ namespace JPH {
 	enum class EMotionType : uint8;
 }
 
+#ifdef JPH_OBJECT_STREAM
+
 enum class EConstraintOverride
 {
 	TypeFixed,
@@ -19,8 +21,16 @@ enum class EConstraintOverride
 	TypeRagdoll,
 };
 
+#endif // JPH_OBJECT_STREAM
+
 class RagdollLoader
 {
 public:
+#ifdef JPH_OBJECT_STREAM
+	/// Load a ragdoll from an ObjectStream file
 	static RagdollSettings *		sLoad(const char *inFileName, EMotionType inMotionType, EConstraintOverride inConstraintOverride = EConstraintOverride::TypeRagdoll);
+#endif // JPH_OBJECT_STREAM
+
+	/// Create a ragdoll from code
+	static RagdollSettings *		sCreate();
 };
