@@ -30,6 +30,9 @@ protected:
 	/// Debug renderer module
 	DebugRenderer *				mDebugRenderer;
 
+	/// Main window
+	ApplicationWindow *			mWindow;
+
 	/// Render module
 	Renderer *					mRenderer;
 
@@ -49,9 +52,12 @@ protected:
 
 public:
 	/// Constructor
-								Application();
+								Application(const char *inApplicationName, const String &inCommandLine);
 	virtual						~Application();
 
+	/// Create a single string command line
+	static String				sCreateCommandLine(int inArgC, char **inArgV);
+
 	/// Enter the main loop
 	void						Run();
 
@@ -87,6 +93,9 @@ protected:
 	void						ClearDebugRenderer();
 
 private:
+	/// Render a frame
+	bool						RenderFrame();
+
 	/// Extract heading and pitch from the local space (relative to the camera pivot) camera forward
 	void						GetCameraLocalHeadingAndPitch(float &outHeading, float &outPitch);
 
