@@ -7,6 +7,41 @@
 
 TEST_SUITE("VectorTests")
 {
+	TEST_CASE("TestVectorEquals")
+	{
+		Vector<3> v1;
+		v1[0] = 1;
+		v1[1] = 2;
+		v1[2] = 3;
+
+		Vector<3> v2;
+		v2[0] = 1;
+		v2[1] = 2;
+		v2[2] = 3;
+
+		Vector<3> v3;
+		v3[0] = 1;
+		v3[1] = 5;
+		v3[2] = 3;
+
+		CHECK(v1 == v2);
+		CHECK(!(v1 != v2));
+		CHECK(v1 != v3);
+		CHECK(!(v1 == v3));
+	}
+
+	TEST_CASE("TestVectorStream")
+	{
+		Vector<3> v1;
+		v1[0] = 1;
+		v1[1] = 2;
+		v1[2] = 3;
+
+		std::stringstream ss;
+		ss << v1;
+		CHECK(ss.str() == "[1, 2, 3]");
+	}
+
 	TEST_CASE("TestVectorMultiplyFloat")
 	{
 		Vector<5> v;
